==> libreoffice-still-sdk-24.8.7-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/cpp/ref/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "LibreOffice", "index.html", [
    [ "SAL debug areas", "a02539.html", [
      [ "SAL", "a02539.html#SAL", null ],
      [ "basctl", "a02539.html#basctl", null ],
      [ "basic", "a02539.html#basic", null ],
      [ "bridges", "a02539.html#bridges", null ],
      [ "canvas", "a02539.html#canvas", null ],
      [ "chart2", "a02539.html#chart2", null ],
      [ "connectivity", "a02539.html#connectivity", null ],
      [ "comphelper", "a02539.html#comphelper", null ],
      [ "cppu", "a02539.html#cppu", null ],
      [ "cppuhelper", "a02539.html#cppuhelper", null ],
      [ "cpputools", "a02539.html#cpputools", null ],
      [ "cui", "a02539.html#cui", null ],
      [ "drawinglayer", "a02539.html#drawinglayer", null ],
      [ "emfio", "a02539.html#emfio", null ],
      [ "Calc", "a02539.html#Calc", null ],
      [ "desktop", "a02539.html#desktop", null ],
      [ "Draw", "a02539.html#Draw", null ],
      [ "editeng", "a02539.html#editeng", null ],
      [ "embeddedobj", "a02539.html#embeddedobj", null ],
      [ "embedserv", "a02539.html#embedserv", null ],
      [ "extensions", "a02539.html#extensions", null ],
      [ "Filter", "a02539.html#Filter", null ],
      [ "oox", "a02539.html#oox", null ],
      [ "forms", "a02539.html#forms", null ],
      [ "formula", "a02539.html#formula", null ],
      [ "fpicker", "a02539.html#fpicker", null ],
      [ "framework", "a02539.html#framework", null ],
      [ "i18nlangtag", "a02539.html#i18nlangtag", null ],
      [ "i18npool", "a02539.html#i18npool", null ],
      [ "i18n", "a02539.html#i18n", null ],
      [ "io", "a02539.html#io", null ],
      [ "jvmfwk", "a02539.html#jvmfwk", null ],
      [ "LanguageTool", "a02539.html#LanguageTool", null ],
      [ "LibreOfficeKit", "a02539.html#LibreOfficeKit", null ],
      [ "l10ntools", "a02539.html#l10ntools", null ],
      [ "Math", "a02539.html#Math", null ],
      [ "package", "a02539.html#package", null ],
      [ "pyuno", "a02539.html#pyuno", null ],
      [ "sdext", "a02539.html#sdext", null ],
      [ "sfx", "a02539.html#sfx", null ],
      [ "slideshow", "a02539.html#slideshow", null ],
      [ "sot", "a02539.html#sot", null ],
      [ "svl", "a02539.html#svl", null ],
      [ "svtools", "a02539.html#svtools", null ],
      [ "svx", "a02539.html#svx", null ],
      [ "toolkit", "a02539.html#toolkit", null ],
      [ "tools", "a02539.html#tools", null ],
      [ "ucb", "a02539.html#ucb", null ],
      [ "unotools", "a02539.html#unotools", null ],
      [ "URE", "a02539.html#URE", null ],
      [ "sax", "a02539.html#sax", null ],
      [ "stoc", "a02539.html#stoc", null ],
      [ "VCL", "a02539.html#VCL", null ],
      [ "winaccessibility", "a02539.html#winaccessibility", null ],
      [ "Writer", "a02539.html#Writer", null ],
      [ "writerfilter", "a02539.html#writerfilter", null ],
      [ "writerperfect", "a02539.html#writerperfect", null ],
      [ "xmloff", "a02539.html#xmloff", null ],
      [ "xmlsecurity", "a02539.html#xmlsecurity", null ],
      [ "xmlscript", "a02539.html#xmlscript", null ],
      [ "dbaccess", "a02539.html#dbaccess", null ],
      [ "avmedia", "a02539.html#avmedia", null ],
      [ "other", "a02539.html#other", null ]
    ] ],
    [ "Basic logging functionality.", "a02540.html", null ],
    [ "Deprecated List", "a00518.html", null ],
    [ "Todo List", "a00519.html", null ],
    [ "Topics", "topics.html", "topics" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", "globals_eval" ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"a00008.html",
"a00089.html#a7a0aab1e07d35548bd35fe8d6dcadc4f",
"a00134.html#a58b6c23e3f0c473c1cc0978bbed87cbd",
"a00155.html#a63e64d39ab88fe964f91477896156409",
"a00191.html#a8619284a83561b69309d5539d993f384",
"a00233.html#ad6a458e5cd271d46be98eefc4e4193eeae3c75a5a71ee85acb4c1a6cb544a1abf",
"a00284_source.html",
"a00515.html#ae4c66f7bd6c9537d9b3486d6a2cfe52c",
"a00537.html#a40c544d2bca8e51dfe5de92e6f992413",
"a00606.html#a12984b7908f4f5ba1e0c0a37beab9493",
"a00662.html#af53f8981541973984a93c7643ab954d7",
"a00738.html#a11ee8616cb9f36bc97ff20b0b6ce9149",
"a00754.html#a69baba4d68131d28e548d2cfdc7781ed",
"a00774.html#ae2e12b95c2df5b6cab62104982151c7ead65e709bd95e2249fd5e4030f36eed89",
"a00818.html#a6e03c9bc0977153feec3bf8fb4d75543",
"a00858.html#ad019fff4c8534866cad915ecd664dded",
"a00958.html#a003e817c3bb0008ede13dd31e3e4f5c9",
"a01010.html#a5c3e3426d06e79116df6fe56b14095b5",
"a01106.html#a10db36b8dee0bb85dff1a41303d7496a",
"a01226.html#a160d44afd82aa9373645eb86c9bfa556",
"a01338.html#a31b4fdd717e8bcc614920de89a782b4e",
"a01442.html#ae2ed8d65abd4addff709413846e69396",
"a01562.html#a35b1f9330d2a06e54b1d8aac98d4e239",
"a01674.html#a3ba896ecafd4ea522784d1bb4be423bd",
"a01786.html#a30a61820be3bcdfe7137517ca1b0155e",
"a01874.html#aed5cfea5ef94de1e8b63b00223426a44",
"a01930.html#acfa596d84b0e6bf290c8f7605076a5b0",
"a02539.html#basctl",
"globals_h.html"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
var LISTOFALLMEMBERS = 'List of all members';

==> libreoffice-still-sdk-25.2.7-1-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/cpp/ref/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "LibreOffice", "index.html", [
    [ "SAL debug areas", "a02539.html", [
      [ "SAL", "a02539.html#SAL", null ],
      [ "basctl", "a02539.html#basctl", null ],
      [ "basic", "a02539.html#basic", null ],
      [ "bridges", "a02539.html#bridges", null ],
      [ "canvas", "a02539.html#canvas", null ],
      [ "chart2", "a02539.html#chart2", null ],
      [ "connectivity", "a02539.html#connectivity", null ],
      [ "comphelper", "a02539.html#comphelper", null ],
      [ "cppu", "a02539.html#cppu", null ],
      [ "cppuhelper", "a02539.html#cppuhelper", null ],
      [ "cpputools", "a02539.html#cpputools", null ],
      [ "cui", "a02539.html#cui", null ],
      [ "drawinglayer", "a02539.html#drawinglayer", null ],
      [ "emfio", "a02539.html#emfio", null ],
      [ "Calc", "a02539.html#Calc", null ],
      [ "desktop", "a02539.html#desktop", null ],
      [ "Draw", "a02539.html#Draw", null ],
      [ "editeng", "a02539.html#editeng", null ],
      [ "embeddedobj", "a02539.html#embeddedobj", null ],
      [ "embedserv", "a02539.html#embedserv", null ],
      [ "extensions", "a02539.html#extensions", null ],
      [ "Filter", "a02539.html#Filter", null ],
      [ "oox", "a02539.html#oox", null ],
      [ "forms", "a02539.html#forms", null ],
      [ "formula", "a02539.html#formula", null ],
      [ "fpicker", "a02539.html#fpicker", null ],
      [ "framework", "a02539.html#framework", null ],
      [ "i18nlangtag", "a02539.html#i18nlangtag", null ],
      [ "i18npool", "a02539.html#i18npool", null ],
      [ "i18n", "a02539.html#i18n", null ],
      [ "io", "a02539.html#io", null ],
      [ "jvmfwk", "a02539.html#jvmfwk", null ],
      [ "LanguageTool", "a02539.html#LanguageTool", null ],
      [ "LibreOfficeKit", "a02539.html#LibreOfficeKit", null ],
      [ "l10ntools", "a02539.html#l10ntools", null ],
      [ "Math", "a02539.html#Math", null ],
      [ "package", "a02539.html#package", null ],
      [ "pyuno", "a02539.html#pyuno", null ],
      [ "sdext", "a02539.html#sdext", null ],
      [ "sfx", "a02539.html#sfx", null ],
      [ "slideshow", "a02539.html#slideshow", null ],
      [ "sot", "a02539.html#sot", null ],
      [ "svl", "a02539.html#svl", null ],
      [ "svtools", "a02539.html#svtools", null ],
      [ "svx", "a02539.html#svx", null ],
      [ "toolkit", "a02539.html#toolkit", null ],
      [ "tools", "a02539.html#tools", null ],
      [ "ucb", "a02539.html#ucb", null ],
      [ "unotools", "a02539.html#unotools", null ],
      [ "URE", "a02539.html#URE", null ],
      [ "sax", "a02539.html#sax", null ],
      [ "stoc", "a02539.html#stoc", null ],
      [ "VCL", "a02539.html#VCL", null ],
      [ "winaccessibility", "a02539.html#winaccessibility", null ],
      [ "Writer", "a02539.html#Writer", null ],
      [ "writerfilter", "a02539.html#writerfilter", null ],
      [ "writerperfect", "a02539.html#writerperfect", null ],
      [ "xmloff", "a02539.html#xmloff", null ],
      [ "xmlsecurity", "a02539.html#xmlsecurity", null ],
      [ "xmlscript", "a02539.html#xmlscript", null ],
      [ "dbaccess", "a02539.html#dbaccess", null ],
      [ "avmedia", "a02539.html#avmedia", null ],
      [ "other", "a02539.html#other", null ]
    ] ],
    [ "Basic logging functionality.", "a02540.html", null ],
    [ "Deprecated List", "a00518.html", null ],
    [ "Todo List", "a00519.html", null ],
    [ "Topics", "topics.html", "topics" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", "globals_eval" ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"a00008.html",
"a00074.html#aaedbf650b555dbb156ca16e75171f2a4",
"a00119.html#af6d322f4eaa60b559f2066da2f3ba08c",
"a00140.html#aa1fdfdf1683cb98003e07f7ec83bfa39",
"a00203.html#a7c564b14a4ef36ff2f858373524137e3a8241f828a83e2e5b5406c04da3511401",
"a00227.html#ad6a458e5cd271d46be98eefc4e4193eea4c994c1074a0306f0d248f7b23242dbf",
"a00284.html#a7e1a50518a98c70c4100b056cbb32cda",
"a00515.html#ac3f10d1dde9a631a2df769c9eefd1fd3",
"a00537.html#a36808dda29a2ec49670b0b872e75fa13",
"a00606.html#a115f3db0d455ed06cb9616880a607223",
"a00662.html#ae7274338240f53943cb4309f4610277f",
"a00734.html#afb15abd4d6bca742613aa55c342f3082",
"a00754.html#a679d95859f010dbfd55f67cf4fa7c6eb",
"a00774.html#ae2e12b95c2df5b6cab62104982151c7ead08d836585f9f9383392cbd856bdc7c5",
"a00818.html#a3540631a0fd1f38e5538f50ea0b2fd37",
"a00858.html#aca87cea7faea35650e1a359ebce49ce4",
"a00954.html#a451809bc746a147b2ecd3caea7cea703",
"a01010.html#a56de184bc83af0a21d396de4c54f405a",
"a01106.html",
"a01226.html",
"a01338.html#a23ae5b2fc8d0f0a76ba87e39126576fa",
"a01442.html#ac607dea78d8f31f2a58e0caad5cb4e6c",
"a01562.html",
"a01674.html#a365fd92cea2fec7167c41be3019e1766",
"a01786.html",
"a01874.html#a929dd79785e30217bc7d53152c1b455a",
"a01930.html#abb8c71eed2ece02ace5aef144003bac4",
"a02539.html#Writer",
"globals_func_u.html"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
var LISTOFALLMEMBERS = 'List of all members';
